@@ -35,6 +35,7 @@ from azureml.core.run import _OfflineRun
 from azureml.data.azure_storage_datastore import AzureBlobDatastore
 from azureml.train.hyperdrive import HyperDriveRun
 
+
 T = TypeVar("T")
 
 EXPERIMENT_RUN_SEPARATOR = ":"
@@ -54,6 +55,7 @@ ENV_WORKSPACE_NAME = "HIML_WORKSPACE_NAME"
 
 # Environment variables used for multi-node training
 ENV_AZ_BATCHAI_MPI_MASTER_NODE = "AZ_BATCHAI_MPI_MASTER_NODE"
+ENV_AZ_BATCH_MASTER_NODE = "AZ_BATCH_MASTER_NODE"
 ENV_MASTER_ADDR = "MASTER_ADDR"
 ENV_MASTER_IP = "MASTER_IP"
 ENV_MASTER_PORT = "MASTER_PORT"
@@ -61,7 +63,10 @@ ENV_OMPI_COMM_WORLD_RANK = "OMPI_COMM_WORLD_RANK"
 ENV_NODE_RANK = "NODE_RANK"
 ENV_GLOBAL_RANK = "GLOBAL_RANK"
 ENV_LOCAL_RANK = "LOCAL_RANK"
+ENV_RANK = "RANK"
+MASTER_PORT_DEFAULT = 6105
 
+# Other Azure ML related variables
 ENVIRONMENT_VERSION = "1"
 FINAL_MODEL_FOLDER = "final_model"
 MODEL_ID_KEY_NAME = "model_id"
@@ -88,6 +93,7 @@ DEFAULT_ENVIRONMENT_VARIABLES = {
     "RSLEX_DIRECT_VOLUME_MOUNT": "true",
     "RSLEX_DIRECT_VOLUME_MOUNT_MAX_CACHE_SIZE": "1",
     "DATASET_MOUNT_CACHE_SIZE": "1",
+    "AZUREML_COMPUTE_USE_COMMON_RUNTIME": "false"
 }
 
 PathOrString = Union[Path, str]
@@ -609,69 +615,6 @@ class RunIdOrListParam(CustomTypeParam):
         return [determine_run_id_type(x) for x in res]
 
 
-class CheckpointDownloader:
-    def __init__(
-        self,
-        run_id: str,
-        checkpoint_filename: str,
-        azure_config_json_path: Optional[Path] = None,
-        aml_workspace: Workspace = None,
-        download_dir: PathOrString = "checkpoints",
-        remote_checkpoint_dir: PathOrString = "checkpoints",
-    ) -> None:
-        """
-        Utility class for downloading checkpoint files from an Azure ML run
-
-        :param run_id: Recovery ID of the run from which to load the checkpoint.
-        :param checkpoint_filename: Name of the checkpoint file, expected to be inside the
-        `outputs/checkpoints/` directory (e.g. `"best_checkpoint.ckpt"`).
-        :param azure_config_json_path: An optional Azure ML settings (JSON file) to use to access the specified
-            experiment run. If not running inside an AML Run, and no aml_workspace object is provided, this
-            is required.
-        :param aml_workspace: An optional Azure ML Workspace object. If not running inside an AML Run, and no
-            azure_config_json_path is provided, this is required.
-        :param download_dir: The local directory in which to save the downloaded checkpoint files.
-        :param remote_checkpoint_dir: The remote folder from which to download the checkpoint file
-        """
-        self.azure_config_json_path = azure_config_json_path
-        self.aml_workspace = aml_workspace
-        self.run_id = run_id
-        self.checkpoint_filename = checkpoint_filename
-        self.download_dir = Path(download_dir)
-        self.remote_checkpoint_dir = Path(remote_checkpoint_dir)
-
-    @property
-    def local_checkpoint_dir(self) -> Path:
-        # in case we run_id is a run recovery id, extract the run id
-        run_id_parts = self.run_id.split(":")
-        run_id = run_id_parts[-1]
-        return self.download_dir / run_id
-
-    @property
-    def remote_checkpoint_path(self) -> Path:
-        return self.remote_checkpoint_dir / self.checkpoint_filename
-
-    @property
-    def local_checkpoint_path(self) -> Path:
-        return self.local_checkpoint_dir / self.remote_checkpoint_path
-
-    def download_checkpoint_if_necessary(self) -> Path:
-        """Downloads the specified checkpoint if it does not already exist.
-
-        :return: The local path to the downloaded checkpoint file.
-        """
-        workspace = get_workspace(aml_workspace=self.aml_workspace, workspace_config_path=self.azure_config_json_path)
-
-        if not self.local_checkpoint_path.exists():
-            self.local_checkpoint_dir.mkdir(exist_ok=True, parents=True)
-            download_checkpoints_from_run_id(
-                self.run_id, str(self.remote_checkpoint_path), self.local_checkpoint_dir, aml_workspace=workspace
-            )
-            assert self.local_checkpoint_path.exists()
-
-        return self.local_checkpoint_path
-
-
 def is_private_field_name(name: str) -> bool:
     """
     A private field is any Python class member that starts with an underscore eg: _hello
@@ -1219,23 +1162,46 @@ def set_environment_variables_for_multi_node() -> None:
     """
     Sets the environment variables that PyTorch Lightning needs for multi-node training.
     """
-    if ENV_AZ_BATCHAI_MPI_MASTER_NODE in os.environ:
+    if ENV_AZ_BATCH_MASTER_NODE in os.environ:
+        master_node = os.environ[ENV_AZ_BATCH_MASTER_NODE]
+        logging.debug(
+            f"Found AZ_BATCH_MASTER_NODE: {master_node} in environment variables")
         # For AML BATCHAI
-        os.environ[ENV_MASTER_ADDR] = os.environ[ENV_AZ_BATCHAI_MPI_MASTER_NODE]
+        split_master_node_addr = master_node.split(":")
+        if len(split_master_node_addr) == 2:
+            master_addr, port = split_master_node_addr
+            os.environ[ENV_MASTER_PORT] = port
+        elif len(split_master_node_addr) == 1:
+            master_addr = split_master_node_addr[0]
+        else:
+            raise ValueError(f"Format not recognized: {master_node}")
+        os.environ[ENV_MASTER_ADDR] = master_addr
+    elif ENV_AZ_BATCHAI_MPI_MASTER_NODE in os.environ and os.environ.get(ENV_AZ_BATCHAI_MPI_MASTER_NODE) != "localhost":
+        mpi_master_node = os.environ[ENV_AZ_BATCHAI_MPI_MASTER_NODE]
+        logging.debug(
+            f"Found AZ_BATCHAI_MPI_MASTER_NODE: {mpi_master_node} in environment variables")
+        # For AML BATCHAI
+        os.environ[ENV_MASTER_ADDR] = mpi_master_node
     elif ENV_MASTER_IP in os.environ:
+        master_ip = os.environ[ENV_MASTER_IP]
+        logging.debug(
+            f"Found MASTER_IP: {master_ip} in environment variables")
         # AKS
-        os.environ[ENV_MASTER_ADDR] = os.environ[ENV_MASTER_IP]
+        os.environ[ENV_MASTER_ADDR] = master_ip
     else:
         logging.info("No settings for the MPI central node found. Assuming that this is a single node training job.")
         return
 
     if ENV_MASTER_PORT not in os.environ:
-        os.environ[ENV_MASTER_PORT] = "6105"
+        os.environ[ENV_MASTER_PORT] = str(MASTER_PORT_DEFAULT)
 
     if ENV_OMPI_COMM_WORLD_RANK in os.environ:
-        os.environ[ENV_NODE_RANK] = os.environ[ENV_OMPI_COMM_WORLD_RANK]  # node rank is the world_rank from mpi run
+        world_rank = os.environ[ENV_OMPI_COMM_WORLD_RANK]
+        logging.debug(f"Found OMPI_COMM_WORLD_RANK: {world_rank} in environment variables")
+        os.environ[ENV_NODE_RANK] = world_rank  # node rank is the world_rank from mpi run
+
     env_vars = ", ".join(f"{var} = {os.environ[var]}" for var in [ENV_MASTER_ADDR, ENV_MASTER_PORT, ENV_NODE_RANK])
-    print(f"Distributed training: {env_vars}")
+    logging.info(f"Distributed training: {env_vars}")
 
 
 def is_run_and_child_runs_completed(run: Run) -> bool:
@@ -1359,7 +1325,8 @@ def _download_files_from_run(run: Run, output_dir: Path, prefix: str = "", valid
     """
     run_paths = get_run_file_names(run, prefix=prefix)
     if len(run_paths) == 0:
-        raise ValueError("No such files were found for this Run.")
+        prefix_string = f' with prefix "{prefix}"' if prefix else ""
+        raise FileNotFoundError(f"No files{prefix_string} were found for run with ID {run.id}")
 
     for run_path in run_paths:
         output_path = output_dir / run_path
@@ -1914,7 +1881,7 @@ def replace_directory(source: Path, target: Path) -> None:
         assert not target.exists()
 
         shutil.copytree(source, target)
-        shutil.rmtree(source)
+        shutil.rmtree(source, ignore_errors=True)
     else:
         # Outside of Azure ML, it should be much faster to rename the directory
         # than to copy all contents then delete, especially for large dirs.
@@ -1958,7 +1925,7 @@ def create_aml_run_object(
     exp = Experiment(workspace=actual_workspace, name=experiment_name)
     if snapshot_directory is None or snapshot_directory == "":
         snapshot_directory = tempfile.mkdtemp()
-    return exp.start_logging(name=run_name, snapshot_directory=str(snapshot_directory))  # type: ignore
+    return exp.start_logging(display_name=run_name, snapshot_directory=str(snapshot_directory))  # type: ignore
 
 
 def aml_workspace_for_unittests() -> Workspace:
